@@ -24,7 +24,7 @@ use std::{
 #[cfg(feature = "json")]
 use {
     crate::data::json_writer::record_batches_to_json_rows,
-    arrow::{json, json::reader::DecoderOptions},
+    arrow::json,
     serde_json::{json, Value},
     std::{borrow::Cow, convert::TryFrom},
 };
@@ -51,15 +51,15 @@ impl VegaFusionTable {
         let schema_fields: Vec<_> = schema
             .fields
             .iter()
-            .map(|f| f.clone().with_nullable(true))
+            .map(|f| f.as_ref().clone().with_nullable(true))
             .collect();
         let schema = Arc::new(Schema::new(schema_fields));
         if partitions.iter().all(|batches| {
-            let batch_schema_fields = batches
+            let batch_schema_fields: Vec<_> = batches
                 .schema()
                 .fields
                 .iter()
-                .map(|f| f.clone().with_nullable(true))
+                .map(|f| f.as_ref().clone().with_nullable(true))
                 .collect();
             let batch_schema = Arc::new(Schema::new(batch_schema_fields));
             schema.contains(&batch_schema)
@@ -117,7 +117,7 @@ impl VegaFusionTable {
 
     pub fn with_ordering(self) -> Result<Self> {
         // Build new schema with leading ORDER_COL
-        let mut new_fields = self.schema.fields.clone();
+        let mut new_fields = self.schema.fields.to_vec();
         let mut start_idx = 0;
         if new_fields.is_empty() {
             return Ok(Self::empty_with_ordering());
@@ -135,7 +135,7 @@ impl VegaFusionTable {
             new_fields.remove(order_col_index);
         }
 
-        new_fields.insert(0, Field::new(ORDER_COL, ORDER_COL_DTYPE, true));
+        new_fields.insert(0, Arc::new(Field::new(ORDER_COL, ORDER_COL_DTYPE, true)));
 
         let new_schema = Arc::new(Schema::new(new_fields)) as SchemaRef;
 
@@ -182,7 +182,7 @@ impl VegaFusionTable {
             let dtype = DataType::Float64;
             return Ok(ScalarValue::List(
                 Some(Vec::new()),
-                Box::new(Field::new("item", dtype, true)),
+                Arc::new(Field::new("item", dtype, true)),
             ));
         }
 
@@ -201,7 +201,7 @@ impl VegaFusionTable {
         let dtype = elements[0].get_datatype();
         Ok(ScalarValue::List(
             Some(elements),
-            Box::new(Field::new("item", dtype, true)),
+            Arc::new(Field::new("item", dtype, true)),
         ))
     }
 
@@ -215,7 +215,7 @@ impl VegaFusionTable {
     }
 
     #[cfg(feature = "json")]
-    pub fn from_json(value: &serde_json::Value, batch_size: usize) -> Result<Self> {
+    pub fn from_json(value: &serde_json::Value) -> Result<Self> {
         if let serde_json::Value::Array(values) = value {
             // Handle special case where array elements are non-object scalars
             let mut values = Cow::Borrowed(values);
@@ -257,16 +257,15 @@ impl VegaFusionTable {
                     let schema_ref = Arc::new(schema);
 
                     // read record batches
-                    #[allow(deprecated)]
-                    let decoder = json::reader::Decoder::new(
-                        schema_ref.clone(),
-                        DecoderOptions::default().with_batch_size(batch_size),
-                    );
+                    let reader =
+                        json::ReaderBuilder::new(schema_ref.clone()).with_coerce_primitive(true);
+                    let mut decoder = reader.build_decoder()?;
+
                     let mut batches: Vec<RecordBatch> = Vec::new();
-                    let mut value_iter = values.iter().map(|v| Ok(v.clone()));
+                    decoder.serialize(values.as_slice())?;
 
                     while let Some(batch) = decoder
-                        .next_batch(&mut value_iter)
+                        .flush()
                         .with_context(|| "Failed to read json to arrow")?
                     {
                         batches.push(batch);
@@ -391,29 +390,23 @@ mod tests {
 
     #[test]
     fn test_with_ordering() {
-        let table1 = VegaFusionTable::from_json(
-            &json!([
-                {"a": 1, "b": "A"},
-                {"a": 2, "b": "BB"},
-                {"a": 10, "b": "CCC"},
-                {"a": 20, "b": "DDDD"},
-            ]),
-            2,
-        )
+        let table1 = VegaFusionTable::from_json(&json!([
+            {"a": 1, "b": "A"},
+            {"a": 2, "b": "BB"},
+            {"a": 10, "b": "CCC"},
+            {"a": 20, "b": "DDDD"},
+        ]))
         .unwrap();
-        assert_eq!(table1.batches.len(), 2);
+        assert_eq!(table1.batches.len(), 1);
 
-        let table2 = VegaFusionTable::from_json(
-            &json!([
-                {"_vf_order": 10u32, "a": 1, "b": "A"},
-                {"_vf_order": 9u32, "a": 2, "b": "BB"},
-                {"_vf_order": 8u32, "a": 10, "b": "CCC"},
-                {"_vf_order": 7u32, "a": 20, "b": "DDDD"},
-            ]),
-            2,
-        )
+        let table2 = VegaFusionTable::from_json(&json!([
+            {"_vf_order": 10u32, "a": 1, "b": "A"},
+            {"_vf_order": 9u32, "a": 2, "b": "BB"},
+            {"_vf_order": 8u32, "a": 10, "b": "CCC"},
+            {"_vf_order": 7u32, "a": 20, "b": "DDDD"},
+        ]))
         .unwrap();
-        assert_eq!(table2.batches.len(), 2);
+        assert_eq!(table2.batches.len(), 1);
 
         let expected_json = json!([
             {"_vf_order": 0u32, "a": 1, "b": "A"},
@@ -424,12 +417,12 @@ mod tests {
 
         // Add ordering column to table without one
         let result_table1 = table1.with_ordering().unwrap();
-        assert_eq!(result_table1.batches.len(), 2);
+        assert_eq!(result_table1.batches.len(), 1);
         assert_eq!(result_table1.to_json().unwrap(), expected_json);
 
         // Override prior ordering column
         let result_table2 = table2.with_ordering().unwrap();
-        assert_eq!(result_table2.batches.len(), 2);
+        assert_eq!(result_table2.batches.len(), 1);
         assert_eq!(result_table2.to_json().unwrap(), expected_json);
     }
 }
