@@ -1,14 +1,6 @@
-/*
- * VegaFusion
- * Copyright (C) 2022 VegaFusion Technologies LLC
- *
- * This program is distributed under multiple licenses.
- * Please consult the license documentation provided alongside
- * this program the details of the active license.
- */
 use crate::error::Result;
 use crate::planning::dependency_graph::{get_supported_data_variables, scoped_var_for_input_var};
-use crate::proto::gen::tasks::{Variable, VariableNamespace};
+use crate::proto::gen::tasks::Variable;
 use crate::spec::chart::{ChartSpec, MutChartVisitor};
 use crate::spec::data::{DataSpec, DependencyNodeSupported};
 use crate::spec::mark::MarkSpec;
@@ -18,36 +10,18 @@ use crate::task_graph::scope::TaskScope;
 
 use crate::task_graph::graph::ScopedVariable;
 
-use crate::planning::plan::{PlannerConfig, PlannerWarnings};
+use crate::planning::plan::PlannerConfig;
 use std::collections::{HashMap, HashSet};
 
 pub fn extract_server_data(
     client_spec: &mut ChartSpec,
     task_scope: &mut TaskScope,
-    warnings: &mut Vec<PlannerWarnings>,
     config: &PlannerConfig,
 ) -> Result<ChartSpec> {
     let supported_vars = get_supported_data_variables(client_spec, config)?;
 
-    // Check for partially or unsupported data variables
-    for (var, dep) in supported_vars.iter() {
-        if matches!(var.0.ns(), VariableNamespace::Data)
-            && !matches!(dep, DependencyNodeSupported::Supported)
-        {
-            let message = if var.1.is_empty() {
-                format!(
-                    "Some transforms applied to the '{}' dataset are not yet supported",
-                    var.0.name
-                )
-            } else {
-                format!("Some transforms applied to the '{}' dataset with scope {:?} are not yet supported", var.0.name, var.1.as_slice())
-            };
-            warnings.push(PlannerWarnings::UnsupportedTransforms(message));
-        }
-    }
-
     let mut extract_server_visitor =
-        ExtractServerDependenciesVisitor::new(supported_vars, task_scope);
+        ExtractServerDependenciesVisitor::new(supported_vars, task_scope, config);
     client_spec.walk_mut(&mut extract_server_visitor)?;
 
     Ok(extract_server_visitor.server_spec)
@@ -58,12 +32,14 @@ pub struct ExtractServerDependenciesVisitor<'a> {
     pub server_spec: ChartSpec,
     supported_vars: HashMap<ScopedVariable, DependencyNodeSupported>,
     task_scope: &'a mut TaskScope,
+    planner_config: &'a PlannerConfig,
 }
 
 impl<'a> ExtractServerDependenciesVisitor<'a> {
     pub fn new(
         supported_vars: HashMap<ScopedVariable, DependencyNodeSupported>,
         task_scope: &'a mut TaskScope,
+        planner_config: &'a PlannerConfig,
     ) -> Self {
         let server_spec: ChartSpec = ChartSpec {
             schema: "https://vega.github.io/schema/vega/v5.json".into(),
@@ -73,6 +49,7 @@ impl<'a> ExtractServerDependenciesVisitor<'a> {
             server_spec,
             supported_vars,
             task_scope,
+            planner_config,
         }
     }
 }
@@ -92,7 +69,7 @@ impl<'a> MutChartVisitor for ExtractServerDependenciesVisitor<'a> {
                 let mut pipeline_vars = HashSet::new();
                 let mut num_supported = 0;
                 'outer: for (i, tx) in data.transform.iter().enumerate() {
-                    if tx.supported() {
+                    if tx.supported_and_allowed(self.planner_config, self.task_scope, scope) {
                         if let Ok(input_vars) = tx.input_vars() {
                             for input_var in input_vars {
                                 if let Ok(scoped_source_var) =
@@ -174,13 +151,17 @@ impl<'a> MutChartVisitor for ExtractServerDependenciesVisitor<'a> {
                     server_group.data.push(server_data);
                 }
 
-                // Clear everything except name from client spec
-                data.format = None;
-                data.source = None;
-                data.values = None;
-                data.transform = Vec::new();
-                data.on = None;
-                data.url = None;
+                if data.is_selection_store() {
+                    // Don' clear inline values from client for _store datasets
+                } else {
+                    // Clear everything except name from client spec
+                    data.format = None;
+                    data.source = None;
+                    data.values = None;
+                    data.transform = Vec::new();
+                    data.on = None;
+                    data.url = None;
+                }
             }
             _ => {
                 // Nothing to do
