@@ -40,6 +40,9 @@ pub struct ChartSpec {
     #[serde(skip_serializing_if = "Option::is_none")]
     pub title: Option<TitleSpec>,
 
+    #[serde(default, skip_serializing_if = "HashMap::is_empty")]
+    pub usermeta: HashMap<String, Value>,
+
     #[serde(flatten)]
     pub extra: HashMap<String, Value>,
 }
