@@ -2,10 +2,10 @@ use crate::spec::transform::{TransformColumns, TransformSpecTrait};
 use serde::{Deserialize, Serialize};
 use serde_json::Value;
 use std::collections::HashMap;
+use vegafusion_common::escape::unescape_field;
 
 use crate::error::Result;
 use crate::expression::column_usage::{ColumnUsage, DatasetsColumnUsage, VlSelectionFields};
-use crate::expression::escape::unescape_field;
 
 use crate::proto::gen::tasks::Variable;
 use crate::spec::values::Field;
