@@ -7,6 +7,7 @@ use async_trait::async_trait;
 
 use datafusion_expr::{expr, lit, Expr};
 use std::collections::{HashMap, HashSet};
+use std::path::Path;
 
 use std::sync::Arc;
 use tokio::io::AsyncReadExt;
@@ -29,12 +30,11 @@ use vegafusion_core::task_graph::task_value::TaskValue;
 use reqwest_middleware::{ClientBuilder, ClientWithMiddleware};
 use reqwest_retry::{policies::ExponentialBackoff, RetryTransientMiddleware};
 use vegafusion_common::arrow::datatypes::{DataType, Field, Schema};
-use vegafusion_common::arrow::ipc::reader::{FileReader, StreamReader};
-use vegafusion_common::arrow::record_batch::RecordBatch;
 use vegafusion_common::column::flat_col;
 use vegafusion_common::data::table::VegaFusionTable;
 use vegafusion_common::data::ORDER_COL;
 use vegafusion_common::datatypes::{is_integer_datatype, is_string_datatype};
+use vegafusion_core::proto::gen::transforms::transform::TransformKind;
 use vegafusion_core::spec::visitors::extract_inline_dataset;
 use vegafusion_dataframe::connection::Connection;
 use vegafusion_dataframe::csv::CsvReadOptions;
@@ -105,6 +105,15 @@ impl TaskCall for DataUrlTask {
 
         // Load data from URL
         let parse = self.format_type.as_ref().and_then(|fmt| fmt.parse.clone());
+        let file_type = self.format_type.as_ref().and_then(|fmt| fmt.r#type.clone());
+
+        // Vega-Lite sets unspecified file types to "json", so we don't want this to take
+        // precedence over file extension
+        let file_type = if file_type == Some("json".to_string()) {
+            None
+        } else {
+            file_type.as_deref()
+        };
 
         let registered_tables = conn.tables().await?;
         let df = if let Some(inline_name) = extract_inline_dataset(&url) {
@@ -123,11 +132,15 @@ impl TaskCall for DataUrlTask {
                     "No inline dataset named {inline_name}"
                 )));
             }
-        } else if url.ends_with(".csv") || url.ends_with(".tsv") {
-            read_csv(&url, &parse, conn).await?
-        } else if url.ends_with(".json") {
-            read_json(&url, self.batch_size as usize, conn).await?
-        } else if url.ends_with(".arrow") || url.ends_with(".feather") {
+        } else if file_type == Some("csv") || (file_type.is_none() && url.ends_with(".csv")) {
+            read_csv(&url, &parse, conn, false).await?
+        } else if file_type == Some("tsv") || (file_type.is_none() && url.ends_with(".tsv")) {
+            read_csv(&url, &parse, conn, true).await?
+        } else if file_type == Some("json") || (file_type.is_none() && url.ends_with(".json")) {
+            read_json(&url, conn).await?
+        } else if file_type == Some("arrow")
+            || (file_type.is_none() && (url.ends_with(".arrow") || url.ends_with(".feather")))
+        {
             read_arrow(&url, conn).await?
         } else {
             return Err(VegaFusionError::internal(format!(
@@ -317,15 +330,15 @@ async fn process_datetimes(
                             .map(|tz_config| tz_config.default_input_tz.to_string())
                             .unwrap_or_else(|| "UTC".to_string());
 
-                        Expr::ScalarUDF {
+                        Expr::ScalarUDF(expr::ScalarUDF {
                             fun: Arc::new((*STR_TO_UTC_TIMESTAMP_UDF).clone()),
                             args: vec![flat_col(&spec.name), lit(default_input_tz_str)],
-                        }
+                        })
                     } else if is_integer_datatype(dtype) {
                         // Assume Year was parsed numerically, use local time
                         let tz_config =
                             tz_config.with_context(|| "No local timezone info provided")?;
-                        Expr::ScalarUDF {
+                        Expr::ScalarUDF(expr::ScalarUDF {
                             fun: Arc::new((*MAKE_UTC_TIMESTAMP).clone()),
                             args: vec![
                                 flat_col(&spec.name),                        // year
@@ -337,7 +350,7 @@ async fn process_datetimes(
                                 lit(0),                                      // millisecond
                                 lit(tz_config.default_input_tz.to_string()), // time zone
                             ],
-                        }
+                        })
                     } else {
                         continue;
                     };
@@ -376,45 +389,45 @@ async fn process_datetimes(
                     DataType::Timestamp(_, tz) => match tz {
                         Some(tz) => {
                             // Timestamp has explicit timezone
-                            Expr::ScalarUDF {
+                            Expr::ScalarUDF(expr::ScalarUDF {
                                 fun: Arc::new((*TO_UTC_TIMESTAMP_UDF).clone()),
-                                args: vec![flat_col(field.name()), lit(tz.as_str())],
-                            }
+                                args: vec![flat_col(field.name()), lit(tz.as_ref())],
+                            })
                         }
                         _ => {
                             // Naive timestamp, interpret as default_input_tz
                             let tz_config =
                                 tz_config.with_context(|| "No local timezone info provided")?;
 
-                            Expr::ScalarUDF {
+                            Expr::ScalarUDF(expr::ScalarUDF {
                                 fun: Arc::new((*TO_UTC_TIMESTAMP_UDF).clone()),
                                 args: vec![
                                     flat_col(field.name()),
                                     lit(tz_config.default_input_tz.to_string()),
                                 ],
-                            }
+                            })
                         }
                     },
                     DataType::Date64 => {
                         let tz_config =
                             tz_config.with_context(|| "No local timezone info provided")?;
 
-                        Expr::ScalarUDF {
+                        Expr::ScalarUDF(expr::ScalarUDF {
                             fun: Arc::new((*TO_UTC_TIMESTAMP_UDF).clone()),
                             args: vec![
                                 flat_col(field.name()),
                                 lit(tz_config.default_input_tz.to_string()),
                             ],
-                        }
+                        })
                     }
                     DataType::Date32 => {
                         let tz_config =
                             tz_config.with_context(|| "No local timezone info provided")?;
 
-                        Expr::ScalarUDF {
+                        Expr::ScalarUDF(expr::ScalarUDF {
                             fun: Arc::new((*DATE_TO_UTC_TIMESTAMP_UDF).clone()),
                             args: vec![flat_col(field.name()), lit(tz_config.local_tz.to_string())],
-                        }
+                        })
                     }
                     _ => flat_col(field.name()),
                 };
@@ -448,6 +461,18 @@ impl TaskCall for DataValuesTask {
             return Ok((TaskValue::Table(values_table), Default::default()));
         }
 
+        // Return early for empty input data unless first transform is a sequence
+        // (which generates its own data)
+        if values_table.num_rows() == 0 {
+            if let Some(pipeline) = &self.pipeline {
+                if let Some(first_tx) = pipeline.transforms.get(0) {
+                    if !matches!(first_tx.transform_kind(), TransformKind::Sequence(_)) {
+                        return Ok((TaskValue::Table(values_table), Default::default()));
+                    }
+                }
+            }
+        }
+
         // Add ordering column
         let values_table = values_table.with_ordering()?;
 
@@ -534,18 +559,25 @@ async fn read_csv(
     url: &str,
     parse: &Option<Parse>,
     conn: Arc<dyn Connection>,
+    is_tsv: bool,
 ) -> Result<Arc<dyn DataFrame>> {
     // Build base CSV options
-    let mut csv_opts = if url.ends_with(".tsv") {
+    let mut csv_opts = if is_tsv {
         CsvReadOptions {
             delimiter: b'\t',
-            file_extension: ".tsv".to_string(),
             ..Default::default()
         }
     } else {
         Default::default()
     };
 
+    // Add file extension based on URL
+    if let Some(ext) = Path::new(url).extension().and_then(|ext| ext.to_str()) {
+        csv_opts.file_extension = ext.to_string();
+    } else {
+        csv_opts.file_extension = "".to_string();
+    }
+
     // Build schema from Vega parse options
     let schema = build_csv_schema(parse);
     csv_opts.schema = schema;
@@ -588,11 +620,7 @@ fn build_csv_schema(parse: &Option<Parse>) -> Option<Schema> {
     Some(Schema::new(new_fields))
 }
 
-async fn read_json(
-    url: &str,
-    batch_size: usize,
-    conn: Arc<dyn Connection>,
-) -> Result<Arc<dyn DataFrame>> {
+async fn read_json(url: &str, conn: Arc<dyn Connection>) -> Result<Arc<dyn DataFrame>> {
     // Read to json Value from local file or url.
     let value: serde_json::Value = if url.starts_with("http://") || url.starts_with("https://") {
         // Perform get request to collect file contents as text
@@ -620,64 +648,13 @@ async fn read_json(
         serde_json::from_str(&json_str)?
     };
 
-    let table = VegaFusionTable::from_json(&value, batch_size)?.with_ordering()?;
+    let table = VegaFusionTable::from_json(&value)?.with_ordering()?;
 
     conn.scan_arrow(table).await
 }
 
 async fn read_arrow(url: &str, conn: Arc<dyn Connection>) -> Result<Arc<dyn DataFrame>> {
-    // Read to json Value from local file or url.
-    let buffer = if url.starts_with("http://") || url.starts_with("https://") {
-        // Perform get request to collect file contents as text
-        make_request_client()
-            .get(url)
-            .send()
-            .await
-            .external(&format!("Failed to get URL data from {url}"))?
-            .bytes()
-            .await
-            .external("Failed to convert URL data to text")?
-    } else {
-        // Assume local file
-        let mut file = tokio::fs::File::open(url)
-            .await
-            .external(format!("Failed to open as local file: {url}"))?;
-
-        let mut buffer: Vec<u8> = Vec::new();
-        file.read_to_end(&mut buffer)
-            .await
-            .external("Failed to read file contents")?;
-
-        bytes::Bytes::from(buffer)
-    };
-
-    let reader = std::io::Cursor::new(buffer);
-
-    // Try parsing file as both File and IPC formats
-    let (schema, batches) = if let Ok(arrow_reader) = FileReader::try_new(reader.clone(), None) {
-        let schema = arrow_reader.schema();
-        let mut batches: Vec<RecordBatch> = Vec::new();
-        for v in arrow_reader {
-            batches.push(v.with_context(|| "Failed to read arrow batch".to_string())?);
-        }
-        (schema, batches)
-    } else if let Ok(arrow_reader) = StreamReader::try_new(reader.clone(), None) {
-        let schema = arrow_reader.schema();
-        let mut batches: Vec<RecordBatch> = Vec::new();
-        for v in arrow_reader {
-            batches.push(v.with_context(|| "Failed to read arrow batch".to_string())?);
-        }
-        (schema, batches)
-    } else {
-        let _f = FileReader::try_new(reader, None).unwrap();
-        return Err(VegaFusionError::parse(format!(
-            "Failed to read arrow file at {url}"
-        )));
-    };
-
-    let table = VegaFusionTable::try_new(schema, batches)?.with_ordering()?;
-
-    conn.scan_arrow(table).await
+    conn.scan_arrow_file(url).await
 }
 
 pub fn make_request_client() -> ClientWithMiddleware {
