@@ -65,13 +65,14 @@ mod test_compile {
     use crate::task_graph::timezone::RuntimeTzConfig;
     use datafusion_common::{DFSchema, ScalarValue};
     use datafusion_expr::expr::{BinaryExpr, Case, Cast};
-    use datafusion_expr::{concat, lit, BuiltinScalarFunction, Expr, Operator};
+    use datafusion_expr::{concat, expr, lit, BuiltinScalarFunction, Expr, Operator};
     use std::collections::HashMap;
     use std::convert::TryFrom;
     use std::ops::Deref;
     use std::sync::Arc;
     use vegafusion_common::arrow::datatypes::{DataType, Field, Schema};
     use vegafusion_common::column::flat_col;
+    use vegafusion_core::arrow::datatypes::Fields;
     use vegafusion_datafusion_udfs::udfs::array::constructor::ARRAY_CONSTRUCTOR_UDF;
     use vegafusion_datafusion_udfs::udfs::object::make_object_constructor_udf;
 
@@ -170,7 +171,7 @@ mod test_compile {
         println!("expr: {result_expr:?}");
 
         // unary not should cast numeric value to boolean
-        let expected_expr = Expr::ScalarFunction {
+        let expected_expr = Expr::ScalarFunction(expr::ScalarFunction {
             fun: BuiltinScalarFunction::Coalesce,
             args: vec![
                 Expr::Cast(Cast {
@@ -179,7 +180,7 @@ mod test_compile {
                 }),
                 lit(false),
             ],
-        }
+        })
         .not();
 
         assert_eq!(result_expr, expected_expr);
@@ -201,7 +202,7 @@ mod test_compile {
         let expected_expr = Expr::Case(Case {
             expr: None,
             when_then_expr: vec![(
-                Box::new(Expr::ScalarFunction {
+                Box::new(Expr::ScalarFunction(expr::ScalarFunction {
                     fun: BuiltinScalarFunction::Coalesce,
                     args: vec![
                         Expr::Cast(Cast {
@@ -210,7 +211,7 @@ mod test_compile {
                         }),
                         lit(false),
                     ],
-                }),
+                })),
                 Box::new(lit(7.0)),
             )],
             else_expr: Some(Box::new(lit(9.0))),
@@ -256,7 +257,7 @@ mod test_compile {
         let expected_expr = Expr::Case(Case {
             expr: None,
             when_then_expr: vec![(
-                Box::new(Expr::ScalarFunction {
+                Box::new(Expr::ScalarFunction(expr::ScalarFunction {
                     fun: BuiltinScalarFunction::Coalesce,
                     args: vec![
                         Expr::Cast(Cast {
@@ -265,7 +266,7 @@ mod test_compile {
                         }),
                         lit(false),
                     ],
-                }),
+                })),
                 Box::new(lit(55.0)),
             )],
             else_expr: Some(Box::new(lit(5.0))),
@@ -389,10 +390,10 @@ mod test_compile {
         let expr = parse("[1, 2, 3]").unwrap();
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
 
-        let expected_expr = Expr::ScalarUDF {
+        let expected_expr = Expr::ScalarUDF(expr::ScalarUDF {
             fun: Arc::new(ARRAY_CONSTRUCTOR_UDF.deref().clone()),
             args: vec![lit(1.0), lit(2.0), lit(3.0)],
-        };
+        });
         println!("expr: {result_expr:?}");
         assert_eq!(result_expr, expected_expr);
 
@@ -405,7 +406,7 @@ mod test_compile {
                 ScalarValue::from(2.0),
                 ScalarValue::from(3.0),
             ]),
-            Box::new(Field::new("item", DataType::Float64, true)),
+            Arc::new(Field::new("item", DataType::Float64, true)),
         );
 
         println!("value: {result_value:?}");
@@ -417,10 +418,10 @@ mod test_compile {
         let expr = parse("[]").unwrap();
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
 
-        let expected_expr = Expr::ScalarUDF {
+        let expected_expr = Expr::ScalarUDF(expr::ScalarUDF {
             fun: Arc::new(ARRAY_CONSTRUCTOR_UDF.deref().clone()),
             args: vec![],
-        };
+        });
         println!("expr: {result_expr:?}");
         assert_eq!(result_expr, expected_expr);
 
@@ -429,7 +430,7 @@ mod test_compile {
 
         let expected_value = ScalarValue::List(
             Some(vec![]),
-            Box::new(Field::new("item", DataType::Float64, true)),
+            Arc::new(Field::new("item", DataType::Float64, true)),
         );
 
         println!("value: {result_value:?}");
@@ -441,23 +442,23 @@ mod test_compile {
         let expr = parse("[[1, 2], [3, 4], [5, 6]]").unwrap();
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
 
-        let expected_expr = Expr::ScalarUDF {
+        let expected_expr = Expr::ScalarUDF(expr::ScalarUDF {
             fun: Arc::new(ARRAY_CONSTRUCTOR_UDF.deref().clone()),
             args: vec![
-                Expr::ScalarUDF {
+                Expr::ScalarUDF(expr::ScalarUDF {
                     fun: Arc::new(ARRAY_CONSTRUCTOR_UDF.deref().clone()),
                     args: vec![lit(1.0), lit(2.0)],
-                },
-                Expr::ScalarUDF {
+                }),
+                Expr::ScalarUDF(expr::ScalarUDF {
                     fun: Arc::new(ARRAY_CONSTRUCTOR_UDF.deref().clone()),
                     args: vec![lit(3.0), lit(4.0)],
-                },
-                Expr::ScalarUDF {
+                }),
+                Expr::ScalarUDF(expr::ScalarUDF {
                     fun: Arc::new(ARRAY_CONSTRUCTOR_UDF.deref().clone()),
                     args: vec![lit(5.0), lit(6.0)],
-                },
+                }),
             ],
-        };
+        });
         println!("expr: {result_expr:?}");
         assert_eq!(result_expr, expected_expr);
 
@@ -467,20 +468,20 @@ mod test_compile {
             Some(vec![
                 ScalarValue::List(
                     Some(vec![ScalarValue::from(1.0), ScalarValue::from(2.0)]),
-                    Box::new(Field::new("item", DataType::Float64, true)),
+                    Arc::new(Field::new("item", DataType::Float64, true)),
                 ),
                 ScalarValue::List(
                     Some(vec![ScalarValue::from(3.0), ScalarValue::from(4.0)]),
-                    Box::new(Field::new("item", DataType::Float64, true)),
+                    Arc::new(Field::new("item", DataType::Float64, true)),
                 ),
                 ScalarValue::List(
                     Some(vec![ScalarValue::from(5.0), ScalarValue::from(6.0)]),
-                    Box::new(Field::new("item", DataType::Float64, true)),
+                    Arc::new(Field::new("item", DataType::Float64, true)),
                 ),
             ]),
-            Box::new(Field::new(
+            Arc::new(Field::new(
                 "item",
-                DataType::List(Box::new(Field::new("item", DataType::Float64, true))),
+                DataType::List(Arc::new(Field::new("item", DataType::Float64, true))),
                 true,
             )),
         );
@@ -494,25 +495,29 @@ mod test_compile {
         let expr = parse("{a: 1, 'two': {three: 3}}").unwrap();
         let result_expr = compile(&expr, &Default::default(), None).unwrap();
 
-        let expected_expr = Expr::ScalarUDF {
+        let expected_expr = Expr::ScalarUDF(expr::ScalarUDF {
             fun: Arc::new(make_object_constructor_udf(
                 &["a".to_string(), "two".to_string()],
                 &[
                     DataType::Float64,
-                    DataType::Struct(vec![Field::new("three", DataType::Float64, true)]),
+                    DataType::Struct(Fields::from(vec![Field::new(
+                        "three",
+                        DataType::Float64,
+                        true,
+                    )])),
                 ],
             )),
             args: vec![
                 lit(1.0),
-                Expr::ScalarUDF {
+                Expr::ScalarUDF(expr::ScalarUDF {
                     fun: Arc::new(make_object_constructor_udf(
                         &["three".to_string()],
                         &[DataType::Float64],
                     )),
                     args: vec![lit(3.0)],
-                },
+                }),
             ],
-        };
+        });
 
         println!("expr: {result_expr:?}");
         assert_eq!(result_expr, expected_expr);
@@ -575,7 +580,7 @@ mod test_compile {
         // let expr = parse("[datum['two'].foo * 3, datum['two'].foo]").unwrap();
         let foo_field = Field::new("foo", DataType::Float64, true);
 
-        let two_type = DataType::Struct(vec![foo_field]);
+        let two_type = DataType::Struct(Fields::from(vec![foo_field]));
         let two_field = Field::new("two", two_type, true);
         let schema = Schema::new(vec![two_field]);
         let schema = DFSchema::try_from(schema).unwrap();
@@ -610,7 +615,7 @@ mod test_compile {
         let expected_expr = Expr::Case(Case {
             expr: None,
             when_then_expr: vec![(
-                Box::new(Expr::ScalarFunction {
+                Box::new(Expr::ScalarFunction(expr::ScalarFunction {
                     fun: BuiltinScalarFunction::Coalesce,
                     args: vec![
                         Expr::Cast(Cast {
@@ -619,7 +624,7 @@ mod test_compile {
                         }),
                         lit(false),
                     ],
-                }),
+                })),
                 Box::new(lit(7.0)),
             )],
             else_expr: Some(Box::new(lit(9.0))),
