@@ -3,7 +3,8 @@ use crate::compile::order::ToSqlOrderByExpr;
 use crate::compile::select::ToSqlSelectItem;
 use crate::connection::SqlConnection;
 use crate::dialect::{Dialect, ValuesMode};
-use arrow::datatypes::{Field, Schema, SchemaRef};
+use arrow::datatypes::{DataType, Field, FieldRef, Fields, Schema, SchemaRef};
+use arrow::record_batch::RecordBatch;
 use async_trait::async_trait;
 use datafusion_common::{Column, DFSchema, OwnedTableReference, ScalarValue};
 use datafusion_expr::{
@@ -90,7 +91,10 @@ impl DataFrame for SqlDataFrame {
 
     async fn collect(&self) -> Result<VegaFusionTable> {
         let query_string = self.as_query().to_string();
-        self.conn.fetch_query(&query_string, &self.schema).await
+        self.conn
+            .fetch_query(&query_string, &self.schema)
+            .await
+            .and_then(pre_process_column_types)
     }
 
     async fn sort(&self, expr: Vec<Expr>, limit: Option<i32>) -> Result<Arc<dyn DataFrame>> {
@@ -472,7 +476,8 @@ impl SqlDataFrame {
         )?;
 
         // Build new schema
-        let new_schema = make_new_schema_from_exprs(self.schema.as_ref(), expr.as_slice())?;
+        let new_schema =
+            make_new_schema_from_exprs(self.schema.as_ref(), expr.as_slice(), self.dialect())?;
 
         self.chain_query(query, new_schema)
     }
@@ -525,8 +530,11 @@ impl SqlDataFrame {
         };
 
         // Build new schema from aggregate expressions
-        let new_schema =
-            make_new_schema_from_exprs(self.schema.as_ref(), all_aggr_expr.as_slice())?;
+        let new_schema = make_new_schema_from_exprs(
+            self.schema.as_ref(),
+            all_aggr_expr.as_slice(),
+            self.dialect(),
+        )?;
         self.chain_query(query, new_schema)
     }
 
@@ -624,8 +632,11 @@ impl SqlDataFrame {
         // Build new schema
         let mut new_schema_exprs = input_col_exprs;
         new_schema_exprs.extend(aggr_expr);
-        let new_schema =
-            make_new_schema_from_exprs(self.schema.as_ref(), new_schema_exprs.as_slice())?;
+        let new_schema = make_new_schema_from_exprs(
+            self.schema.as_ref(),
+            new_schema_exprs.as_slice(),
+            self.dialect(),
+        )?;
 
         if sql_group_expr_strs.is_empty() {
             self.chain_query_str(
@@ -783,8 +794,11 @@ impl SqlDataFrame {
         let sql =
             format!("SELECT {selection_csv} FROM ({union_subquery}) as {union_subquery_name}");
 
-        let new_schmea =
-            make_new_schema_from_exprs(self.schema.as_ref(), subquery_exprs[0].as_slice())?;
+        let new_schmea = make_new_schema_from_exprs(
+            self.schema.as_ref(),
+            subquery_exprs[0].as_slice(),
+            self.dialect(),
+        )?;
         let dataframe = self.chain_query_str(&sql, new_schmea)?;
 
         if let Some(order_field) = order_field {
@@ -863,10 +877,10 @@ impl SqlDataFrame {
         // Build partitioning column expressions
         let partition_by: Vec<_> = groupby.iter().map(|group| flat_col(group)).collect();
 
-        let numeric_field = Expr::ScalarFunction {
+        let numeric_field = Expr::ScalarFunction(expr::ScalarFunction {
             fun: BuiltinScalarFunction::Coalesce,
             args: vec![to_numeric(flat_col(field), &self.schema_df()?)?, lit(0.0)],
-        };
+        });
 
         if let StackMode::Zero = mode {
             // Build window expression
@@ -895,8 +909,11 @@ impl SqlDataFrame {
             // values stack in the negative direction and positive values stack in the positive
             // direction.
             let schema_exprs = vec![Expr::Wildcard, window_expr];
-            let new_schema =
-                make_new_schema_from_exprs(self.schema.as_ref(), schema_exprs.as_slice())?;
+            let new_schema = make_new_schema_from_exprs(
+                self.schema.as_ref(),
+                schema_exprs.as_slice(),
+                self.dialect(),
+            )?;
 
             let dataframe = self
                 .chain_query_str(&format!(
@@ -950,6 +967,7 @@ impl SqlDataFrame {
                 args: vec![flat_col(stack_col_name)],
                 distinct: false,
                 filter: None,
+                order_by: None,
             })
             .alias("__total");
             let total_agg_str = total_agg
@@ -958,8 +976,11 @@ impl SqlDataFrame {
 
             // Add __total column with total or total per partition
             let schema_exprs = vec![Expr::Wildcard, total_agg];
-            let new_schema =
-                make_new_schema_from_exprs(&dataframe.schema(), schema_exprs.as_slice())?;
+            let new_schema = make_new_schema_from_exprs(
+                &dataframe.schema(),
+                schema_exprs.as_slice(),
+                self.dialect(),
+            )?;
 
             let dataframe = if partition_by.is_empty() {
                 dataframe.chain_query_str(
@@ -1031,8 +1052,11 @@ impl SqlDataFrame {
 
                     // Compute new schema
                     let schema_exprs = vec![Expr::Wildcard, max_total];
-                    let new_schema =
-                        make_new_schema_from_exprs(&dataframe.schema(), schema_exprs.as_slice())?;
+                    let new_schema = make_new_schema_from_exprs(
+                        &dataframe.schema(),
+                        schema_exprs.as_slice(),
+                        self.dialect(),
+                    )?;
 
                     let sqldataframe = dataframe
                         .as_any()
@@ -1105,11 +1129,12 @@ impl SqlDataFrame {
                 .iter()
                 .map(|f| {
                     let col_name = f.name();
+
                     if col_name == field {
-                        Expr::ScalarFunction {
+                        Expr::ScalarFunction(expr::ScalarFunction {
                             fun: BuiltinScalarFunction::Coalesce,
                             args: vec![flat_col(field), lit(value.clone())],
-                        }
+                        })
                         .alias(col_name)
                     } else {
                         flat_col(col_name)
@@ -1151,10 +1176,10 @@ impl SqlDataFrame {
                 .iter()
                 .map(|col_name| {
                     if col_name == field {
-                        Expr::ScalarFunction {
+                        Expr::ScalarFunction(expr::ScalarFunction {
                             fun: BuiltinScalarFunction::Coalesce,
                             args: vec![flat_col(field), lit(value.clone())],
-                        }
+                        })
                         .alias(col_name)
                     } else {
                         flat_col(col_name)
@@ -1169,10 +1194,10 @@ impl SqlDataFrame {
                     .iter()
                     .map(|col_name| {
                         let expr = if col_name == field {
-                            Expr::ScalarFunction {
+                            Expr::ScalarFunction(expr::ScalarFunction {
                                 fun: BuiltinScalarFunction::Coalesce,
                                 args: vec![flat_col(field), lit(value.clone())],
-                            }
+                            })
                             .alias(col_name)
                         } else if col_name == key {
                             Expr::Column(Column {
@@ -1233,8 +1258,11 @@ impl SqlDataFrame {
                     min(flat_col(order_field)).alias(format!("{order_field}_key")),
                     min(flat_col(order_field)).alias(format!("{order_field}_groups")),
                 ]);
-                let new_schema =
-                    make_new_schema_from_exprs(self.schema.as_ref(), schema_exprs.as_slice())?;
+                let new_schema = make_new_schema_from_exprs(
+                    self.schema.as_ref(),
+                    schema_exprs.as_slice(),
+                    self.dialect(),
+                )?;
                 let dataframe = self.chain_query_str(&sql, new_schema)?;
 
                 // Override ordering column since null values may have been introduced in the query above.
@@ -1334,20 +1362,27 @@ impl SqlDataFrame {
                     using_csv = using_csv,
                     parent = self.parent_name(),
                 );
-                let new_schema =
-                    make_new_schema_from_exprs(self.schema.as_ref(), select_columns.as_slice())?;
+                let new_schema = make_new_schema_from_exprs(
+                    self.schema.as_ref(),
+                    select_columns.as_slice(),
+                    self.dialect(),
+                )?;
                 self.chain_query_str(&sql, new_schema)
             }
         }
     }
 }
 
-fn make_new_schema_from_exprs(schema: &Schema, exprs: &[Expr]) -> Result<Schema> {
+fn make_new_schema_from_exprs(
+    schema: &Schema,
+    exprs: &[Expr],
+    dialect: &Dialect,
+) -> Result<Schema> {
     let mut fields: Vec<Field> = Vec::new();
     for expr in exprs {
         if let Expr::Wildcard = expr {
             // Add field for each input schema field
-            fields.extend(schema.fields().clone())
+            fields.extend(schema.fields().iter().map(|f| f.as_ref().clone()));
         } else {
             // Add field for expression
             let schema_df = DFSchema::try_from(schema.clone())?;
@@ -1358,7 +1393,23 @@ fn make_new_schema_from_exprs(schema: &Schema, exprs: &[Expr]) -> Result<Schema>
     }
 
     let new_schema = Schema::new(fields);
-    Ok(new_schema)
+
+    // Check for columns that differ only by case
+    let num_cols = new_schema.fields.len();
+    let num_unique_cols = new_schema
+        .fields
+        .iter()
+        .map(|f| f.name().to_ascii_lowercase())
+        .collect::<HashSet<_>>()
+        .len();
+
+    if !dialect.supports_mixed_case_identical_columns && num_cols != num_unique_cols {
+        Err(VegaFusionError::sql_not_supported(
+            "Dialect does not support multiple columns that differ only by case",
+        ))
+    } else {
+        Ok(new_schema)
+    }
 }
 
 fn cte_name_for_index(prefix: &str, index: usize) -> String {
@@ -1417,3 +1468,50 @@ fn parse_sql_query(query: &str, dialect: &Dialect) -> Result<Query> {
         Err(VegaFusionError::internal("Parser result empty"))
     }
 }
+
+/// There are some internal issues with LargeUtf8 arrays in Arrow/DataFusion, so cast
+/// these to Utf8 for now
+fn pre_process_column_types(table: VegaFusionTable) -> Result<VegaFusionTable> {
+    // Build new Schema
+    let new_field_refs = table
+        .schema
+        .fields
+        .into_iter()
+        .map(|f| {
+            if f.data_type() == &DataType::LargeUtf8 {
+                Arc::new(Field::new(f.name(), DataType::Utf8, true)) as FieldRef
+            } else {
+                f.clone()
+            }
+        })
+        .collect::<Vec<_>>();
+
+    let new_fields = Fields::from(new_field_refs);
+    let new_schema = Schema::new(new_fields);
+
+    // Build new record batches
+    let new_batches = table
+        .batches
+        .into_iter()
+        .map(|batch| {
+            let new_columns = batch
+                .columns()
+                .iter()
+                .map(|c| {
+                    if c.data_type() == &DataType::LargeUtf8 {
+                        Ok(arrow::compute::cast(c, &DataType::Utf8)?)
+                    } else {
+                        Ok(c.clone())
+                    }
+                })
+                .collect::<Result<Vec<_>>>()?;
+
+            Ok(RecordBatch::try_new(
+                Arc::new(new_schema.clone()),
+                new_columns,
+            )?)
+        })
+        .collect::<Result<Vec<_>>>()?;
+
+    VegaFusionTable::try_new(Arc::new(new_schema), new_batches)
+}
