@@ -44,7 +44,7 @@ use crate::dialect::transforms::utc_timestamp_to_str::{
 use arrow::datatypes::{DataType, TimeUnit};
 use datafusion_common::scalar::ScalarValue;
 use datafusion_common::DFSchema;
-use datafusion_expr::{lit, ExprSchemable};
+use datafusion_expr::{expr, lit, ExprSchemable};
 use datafusion_expr::{when, Expr, Operator};
 use sqlparser::ast::{
     BinaryOperator as SqlBinaryOperator, DataType as SqlDataType, Expr as SqlExpr,
@@ -185,6 +185,9 @@ pub struct Dialect {
     /// Whether dialect supports -inf, nan, and inf float values.
     /// If false, non-finite values are converted to NULL
     pub supports_non_finite_floats: bool,
+
+    /// Whether dialect supports multiple columns in the same table that differ only by case
+    pub supports_mixed_case_identical_columns: bool,
 }
 
 impl Default for Dialect {
@@ -213,6 +216,7 @@ impl Default for Dialect {
             cast_transformers: Default::default(),
             cast_propagates_null: true,
             supports_non_finite_floats: false,
+            supports_mixed_case_identical_columns: false,
         }
     }
 }
@@ -339,6 +343,7 @@ impl Dialect {
             cast_transformers: Default::default(),
             cast_propagates_null: true,
             supports_non_finite_floats: false,
+            supports_mixed_case_identical_columns: false,
         }
     }
 
@@ -464,6 +469,7 @@ impl Dialect {
             cast_transformers: Default::default(),
             cast_propagates_null: true,
             supports_non_finite_floats: true,
+            supports_mixed_case_identical_columns: false,
         }
     }
 
@@ -562,6 +568,7 @@ impl Dialect {
             cast_transformers: Default::default(),
             cast_propagates_null: false,
             supports_non_finite_floats: true,
+            supports_mixed_case_identical_columns: true,
         }
     }
 
@@ -703,6 +710,7 @@ impl Dialect {
             cast_transformers: Default::default(),
             cast_propagates_null: true,
             supports_non_finite_floats: true,
+            supports_mixed_case_identical_columns: false,
         }
     }
 
@@ -851,6 +859,7 @@ impl Dialect {
             .collect(),
             cast_propagates_null: true,
             supports_non_finite_floats: true,
+            supports_mixed_case_identical_columns: true,
         }
     }
 
@@ -999,6 +1008,7 @@ impl Dialect {
             cast_transformers: Default::default(),
             cast_propagates_null: true,
             supports_non_finite_floats: true,
+            supports_mixed_case_identical_columns: false,
         }
     }
 
@@ -1098,6 +1108,7 @@ impl Dialect {
             .collect(),
             cast_propagates_null: true,
             supports_non_finite_floats: false,
+            supports_mixed_case_identical_columns: false,
         }
     }
 
@@ -1247,6 +1258,7 @@ impl Dialect {
             cast_transformers: Default::default(),
             cast_propagates_null: true,
             supports_non_finite_floats: true,
+            supports_mixed_case_identical_columns: true,
         }
     }
 
@@ -1382,6 +1394,7 @@ impl Dialect {
             .collect(),
             cast_propagates_null: false,
             supports_non_finite_floats: true,
+            supports_mixed_case_identical_columns: false,
         }
     }
 
@@ -1517,6 +1530,7 @@ impl Dialect {
             cast_transformers: Default::default(),
             cast_propagates_null: true,
             supports_non_finite_floats: true,
+            supports_mixed_case_identical_columns: true,
         }
     }
 }
@@ -1799,11 +1813,11 @@ impl IsFiniteWithNotInTransformer {
 }
 impl FunctionTransformer for IsFiniteWithNotInTransformer {
     fn transform(&self, args: &[Expr], dialect: &Dialect, schema: &DFSchema) -> Result<SqlExpr> {
-        let isfinite_expr = Expr::InList {
+        let isfinite_expr = Expr::InList(expr::InList {
             expr: Box::new(args[0].clone()),
             list: vec![lit(f64::NEG_INFINITY), lit(f64::INFINITY), lit(f64::NAN)],
             negated: false,
-        }
+        })
         .not();
         isfinite_expr.to_sql(dialect, schema)
     }
@@ -1832,7 +1846,7 @@ impl IsFiniteWithNotInStringsTransformer {
 impl FunctionTransformer for IsFiniteWithNotInStringsTransformer {
     fn transform(&self, args: &[Expr], dialect: &Dialect, schema: &DFSchema) -> Result<SqlExpr> {
         let arg_string = args[0].clone().cast_to(&DataType::Utf8, schema)?;
-        let isfinite_expr = Expr::InList {
+        let isfinite_expr = Expr::InList(expr::InList {
             expr: Box::new(arg_string),
             list: vec![
                 lit(f64::NEG_INFINITY).cast_to(&DataType::Utf8, schema)?,
@@ -1840,7 +1854,7 @@ impl FunctionTransformer for IsFiniteWithNotInStringsTransformer {
                 lit(f64::NAN).cast_to(&DataType::Utf8, schema)?,
             ],
             negated: true,
-        };
+        });
         isfinite_expr.to_sql(dialect, schema)
     }
 }
