@@ -20,17 +20,14 @@ mod test_simple_aggs {
         println!("{dialect_name}");
         let (conn, evaluable) = TOKIO_RUNTIME.block_on(make_connection(dialect_name));
 
-        let table = VegaFusionTable::from_json(
-            &json!([
-                {"a": 1, "b": 2, "c": "A"},
-                {"a": 3, "b": 2, "c": "BB"},
-                {"a": 5, "b": 3, "c": "CCC"},
-                {"a": 7, "b": 3, "c": "DDDD"},
-                {"a": 9, "b": 3, "c": "EEEEE"},
-                {"a": 11, "b": 3, "c": "FFFFFF"},
-            ]),
-            1024,
-        )
+        let table = VegaFusionTable::from_json(&json!([
+            {"a": 1, "b": 2, "c": "A"},
+            {"a": 3, "b": 2, "c": "BB"},
+            {"a": 5, "b": 3, "c": "CCC"},
+            {"a": 7, "b": 3, "c": "DDDD"},
+            {"a": 9, "b": 3, "c": "EEEEE"},
+            {"a": 11, "b": 3, "c": "FFFFFF"},
+        ]))
         .unwrap();
 
         let df = SqlDataFrame::from_values(&table, conn, Default::default()).unwrap();
@@ -84,17 +81,14 @@ mod test_simple_aggs_no_grouping {
         println!("{dialect_name}");
         let (conn, evaluable) = TOKIO_RUNTIME.block_on(make_connection(dialect_name));
 
-        let table = VegaFusionTable::from_json(
-            &json!([
-                {"a": 1, "b": 2, "c": "A"},
-                {"a": 3, "b": 2, "c": "BB"},
-                {"a": 5, "b": 3, "c": "CCC"},
-                {"a": 7, "b": 3, "c": "DDDD"},
-                {"a": 9, "b": 3, "c": "EEEEE"},
-                {"a": 11, "b": 3, "c": "FFFFFF"},
-            ]),
-            1024,
-        )
+        let table = VegaFusionTable::from_json(&json!([
+            {"a": 1, "b": 2, "c": "A"},
+            {"a": 3, "b": 2, "c": "BB"},
+            {"a": 5, "b": 3, "c": "CCC"},
+            {"a": 7, "b": 3, "c": "DDDD"},
+            {"a": 9, "b": 3, "c": "EEEEE"},
+            {"a": 11, "b": 3, "c": "FFFFFF"},
+        ]))
         .unwrap();
 
         let df = SqlDataFrame::from_values(&table, conn, Default::default()).unwrap();
