@@ -24,16 +24,13 @@ mod test_simple_aggs_unbounded {
         println!("{dialect_name}");
         let (conn, evaluable) = TOKIO_RUNTIME.block_on(make_connection(dialect_name));
 
-        let table = VegaFusionTable::from_json(
-            &json!([
-                {"a": 1, "b": 2, "c": "A"},
-                {"a": 3, "b": 4, "c": "BB"},
-                {"a": 5, "b": 6, "c": "A"},
-                {"a": 7, "b": 8, "c": "BB"},
-                {"a": 9, "b": 10, "c": "A"},
-            ]),
-            1024,
-        )
+        let table = VegaFusionTable::from_json(&json!([
+            {"a": 1, "b": 2, "c": "A"},
+            {"a": 3, "b": 4, "c": "BB"},
+            {"a": 5, "b": 6, "c": "A"},
+            {"a": 7, "b": 8, "c": "BB"},
+            {"a": 9, "b": 10, "c": "A"},
+        ]))
         .unwrap();
 
         let df = SqlDataFrame::from_values(&table, conn, Default::default()).unwrap();
@@ -91,7 +88,7 @@ mod test_simple_aggs_unbounded {
                     args: vec![flat_col("b")],
                     partition_by: vec![],
                     order_by: order_by.clone(),
-                    window_frame: window_frame,
+                    window_frame,
                 })
                 .alias("max_b"),
             ])
@@ -125,16 +122,13 @@ mod test_simple_aggs_unbounded_groups {
         println!("{dialect_name}");
         let (conn, evaluable) = TOKIO_RUNTIME.block_on(make_connection(dialect_name));
 
-        let table = VegaFusionTable::from_json(
-            &json!([
-                {"a": 1, "b": 2, "c": "A"},
-                {"a": 3, "b": 4, "c": "BB"},
-                {"a": 5, "b": 6, "c": "A"},
-                {"a": 7, "b": 8, "c": "BB"},
-                {"a": 9, "b": 10, "c": "A"},
-            ]),
-            1024,
-        )
+        let table = VegaFusionTable::from_json(&json!([
+            {"a": 1, "b": 2, "c": "A"},
+            {"a": 3, "b": 4, "c": "BB"},
+            {"a": 5, "b": 6, "c": "A"},
+            {"a": 7, "b": 8, "c": "BB"},
+            {"a": 9, "b": 10, "c": "A"},
+        ]))
         .unwrap();
 
         let df = SqlDataFrame::from_values(&table, conn, Default::default()).unwrap();
@@ -192,7 +186,7 @@ mod test_simple_aggs_unbounded_groups {
                     args: vec![flat_col("b")],
                     partition_by: vec![],
                     order_by: order_by.clone(),
-                    window_frame: window_frame,
+                    window_frame,
                 })
                 .alias("max_b"),
             ])
@@ -227,16 +221,13 @@ mod test_simple_aggs_bounded {
         println!("{dialect_name}");
         let (conn, evaluable) = TOKIO_RUNTIME.block_on(make_connection(dialect_name));
 
-        let table = VegaFusionTable::from_json(
-            &json!([
-                {"a": 1, "b": 2, "c": "A"},
-                {"a": 3, "b": 4, "c": "BB"},
-                {"a": 5, "b": 6, "c": "A"},
-                {"a": 7, "b": 8, "c": "BB"},
-                {"a": 9, "b": 10, "c": "A"},
-            ]),
-            1024,
-        )
+        let table = VegaFusionTable::from_json(&json!([
+            {"a": 1, "b": 2, "c": "A"},
+            {"a": 3, "b": 4, "c": "BB"},
+            {"a": 5, "b": 6, "c": "A"},
+            {"a": 7, "b": 8, "c": "BB"},
+            {"a": 9, "b": 10, "c": "A"},
+        ]))
         .unwrap();
 
         let df = SqlDataFrame::from_values(&table, conn, Default::default()).unwrap();
@@ -294,7 +285,7 @@ mod test_simple_aggs_bounded {
                     args: vec![col("b")],
                     partition_by: vec![],
                     order_by: order_by.clone(),
-                    window_frame: window_frame,
+                    window_frame,
                 })
                 .alias("max_b"),
             ])
@@ -328,16 +319,13 @@ mod test_simple_aggs_bounded_groups {
         println!("{dialect_name}");
         let (conn, evaluable) = TOKIO_RUNTIME.block_on(make_connection(dialect_name));
 
-        let table = VegaFusionTable::from_json(
-            &json!([
-                {"a": 1, "b": 2, "c": "A"},
-                {"a": 1, "b": 4, "c": "BB"},
-                {"a": 5, "b": 6, "c": "A"},
-                {"a": 7, "b": 8, "c": "BB"},
-                {"a": 7, "b": 10, "c": "A"},
-            ]),
-            1024,
-        )
+        let table = VegaFusionTable::from_json(&json!([
+            {"a": 1, "b": 2, "c": "A"},
+            {"a": 1, "b": 4, "c": "BB"},
+            {"a": 5, "b": 6, "c": "A"},
+            {"a": 7, "b": 8, "c": "BB"},
+            {"a": 7, "b": 10, "c": "A"},
+        ]))
         .unwrap();
 
         let df = SqlDataFrame::from_values(&table, conn, Default::default()).unwrap();
@@ -395,7 +383,7 @@ mod test_simple_aggs_bounded_groups {
                     args: vec![col("b")],
                     partition_by: vec![],
                     order_by: order_by.clone(),
-                    window_frame: window_frame,
+                    window_frame,
                 })
                 .alias("max_b"),
             ])
@@ -444,16 +432,13 @@ mod test_simple_window_fns {
         println!("{dialect_name}");
         let (conn, evaluable) = TOKIO_RUNTIME.block_on(make_connection(dialect_name));
 
-        let table = VegaFusionTable::from_json(
-            &json!([
-                {"a": 1, "b": 2, "c": "A"},
-                {"a": 3, "b": 4, "c": "BB"},
-                {"a": 5, "b": 6, "c": "A"},
-                {"a": 7, "b": 8, "c": "BB"},
-                {"a": 9, "b": 10, "c": "A"},
-            ]),
-            1024,
-        )
+        let table = VegaFusionTable::from_json(&json!([
+            {"a": 1, "b": 2, "c": "A"},
+            {"a": 3, "b": 4, "c": "BB"},
+            {"a": 5, "b": 6, "c": "A"},
+            {"a": 7, "b": 8, "c": "BB"},
+            {"a": 9, "b": 10, "c": "A"},
+        ]))
         .unwrap();
 
         let df = SqlDataFrame::from_values(&table, conn, Default::default()).unwrap();
@@ -519,7 +504,7 @@ mod test_simple_window_fns {
                     args: vec![col("b")],
                     partition_by: vec![],
                     order_by: order_by.clone(),
-                    window_frame: window_frame,
+                    window_frame,
                 })
                 .alias("last"),
             ])
@@ -553,16 +538,13 @@ mod test_advanced_window_fns {
         println!("{dialect_name}");
         let (conn, evaluable) = TOKIO_RUNTIME.block_on(make_connection(dialect_name));
 
-        let table = VegaFusionTable::from_json(
-            &json!([
-                {"a": 1, "b": 2, "c": "A"},
-                {"a": 3, "b": 4, "c": "BB"},
-                {"a": 5, "b": 6, "c": "A"},
-                {"a": 7, "b": 8, "c": "BB"},
-                {"a": 9, "b": 10, "c": "A"},
-            ]),
-            1024,
-        )
+        let table = VegaFusionTable::from_json(&json!([
+            {"a": 1, "b": 2, "c": "A"},
+            {"a": 3, "b": 4, "c": "BB"},
+            {"a": 5, "b": 6, "c": "A"},
+            {"a": 7, "b": 8, "c": "BB"},
+            {"a": 9, "b": 10, "c": "A"},
+        ]))
         .unwrap();
 
         let df = SqlDataFrame::from_values(&table, conn, Default::default()).unwrap();
@@ -628,7 +610,7 @@ mod test_advanced_window_fns {
                     args: vec![lit(2)],
                     partition_by: vec![],
                     order_by: order_by.clone(),
-                    window_frame: window_frame,
+                    window_frame,
                 })
                 .alias("ntile"),
             ])
